Point2

Struct Point2 

#[repr(C)]
pub struct Point2<U: Unit = f32> { pub x: U::Scalar, pub y: U::Scalar, }
2D point.

Alignment: Same as the scalar.

Fields

x: U::Scalar

X coordinate

y: U::Scalar

Y coordinate

Implementations

Source

impl<T: Unit> Point2<T>

pub const fn new(x: T::Scalar, y: T::Scalar) -> Self

New point.

pub fn from_vector(vec: Vector2<T>) -> Self

Convert a vector to a point as-is.

pub fn to_vector(self) -> Vector2<T>

Cast this point as-is to a vector.

pub fn as_vector(&self) -> &Vector2<T>

Reinterpret as vector.

pub fn as_vector_mut(&mut self) -> &mut Vector2<T>

Reinterpret as vector.

pub fn translate(self, by: Vector2<T>) -> Self

Translate this point by vector.

Equivalent to self + by.

Source

impl<T: Unit> Point2<T>

pub fn splat(scalar: T::Scalar) -> Self

Set all elements to scalar.

pub fn clamp(self, min: Self, max: Self) -> Self

Clamp all elements within min and max.

pub fn min(self, other: Self) -> Self

Return by-element minimum.

pub fn max(self, other: Self) -> Self

Return by-element maximum.

pub fn min_element(self) -> T::Scalar

Min element.

pub fn max_element(self) -> T::Scalar

Max element.

pub fn write_to_slice(self, slice: &mut [T::Scalar])

Write this vector type to a slice.

pub fn with_x(self, x: T::Scalar) -> Self

Replace x component.

pub fn with_y(self, x: T::Scalar) -> Self

Replace y component.

pub fn element_sum(self) -> T::Scalar

Sum of all elements.

pub fn element_product(self) -> T::Scalar

Product of all elements.

pub fn as_array(&self) -> &[T::Scalar; 2]

Reinterpret as array.

pub fn as_array_mut(&mut self) -> &mut [T::Scalar; 2]

Reinterpret as mutable array.

pub fn get(&self, index: usize) -> T::Scalar

Get component at index.

pub fn set(&mut self, index: usize, value: T::Scalar)

Set component at index.

pub fn const_get<const N: usize>(&self) -> T::Scalar

Get component at index N.

pub fn const_set<const N: usize>(&mut self, value: T::Scalar)

Set component at index N.

pub fn map<F: Fn(T::Scalar) -> T::Scalar>(self, f: F) -> Self

Returns a vector containing each element of self modified by a mapping function f.

pub fn from_untyped(untyped: Point2<T::Scalar>) -> Point2<T>

Bitcast an untyped instance to self.

pub fn to_untyped(self) -> Point2<T::Scalar>

Bitcast self to an untyped instance.

pub fn as_untyped(&self) -> &Point2<T::Scalar>

Reinterpret cast self as the untyped variant.

pub fn as_untyped_mut(&mut self) -> &mut Point2<T::Scalar>

Reinterpret cast self as the untyped variant.

pub fn cast<T2>(self) -> Point2<T2>
where T2: Unit<Scalar = T::Scalar>,

Cast to a different coordinate space with the same underlying scalar type.

pub fn cast_ref<T2>(&self) -> &Point2<T2>
where T2: Unit<Scalar = T::Scalar>,

Cast to a different coordinate space with the same underlying scalar type.

pub fn cast_mut<T2>(&mut self) -> &mut Point2<T2>
where T2: Unit<Scalar = T::Scalar>,

Cast to a different coordinate space with the same underlying scalar type.

pub fn as_<T2>(self) -> Point2<T2>
where T: Unit<Scalar: AsPrimitive<T2::Scalar>>, T2: Unit,

Cast to a different coordinate space with scalar type conversion through the as operator (potentially narrowing or losing precision).

pub fn try_cast<T2>(self) -> Option<Point2<T2>>
where T2: Unit,

Cast to a different coordinate space with scalar type conversion. Returns None if any component could not be converted to the target scalar type.

pub fn to_tuple(self) -> (T::Scalar, T::Scalar)

Convert this vector or point to a tuple.

pub fn from_tuple((x, y): (T::Scalar, T::Scalar)) -> Self

Create from tuple.

Source

impl<T: FloatUnit> Point2<T>

pub fn ceil(self) -> Self

Round all components up.

pub fn exp(self) -> Self

e^self by component

pub fn floor(self) -> Self

Round all components down.

pub fn fract(self) -> Self

pub fn fract_gl(self) -> Self

pub fn is_finite(self) -> bool

True if all components are non-infinity and non-NaN.

pub fn is_nan(self) -> bool

True if any component is NaN.

pub fn lerp(self, rhs: Self, s: T::Scalar) -> Self

Linear interpolation.

pub fn powf(self, n: T::Scalar) -> Self

self^n by component

pub fn recip(self) -> Self

1.0/self by component

pub fn round(self) -> Self

Round all components.

pub fn copysign(self, rhs: Self) -> Self

Returns a vector with signs of rhs and the magnitudes of self.

Source

impl<T: SignedUnit> Point2<T>

pub fn signum(self) -> Self

Returns a vector with elements representing the sign of self.

pub fn abs(self) -> Self

Returns a vector containing the absolute value of each element of self.

pub fn rem_euclid(self, rhs: Self) -> Self

Returns the element-wise remainder of Euclidean division of self`` by rhs`.

Panics

This function will panic if any rhs element is 0 or the division results in overflow.

Source

impl<T: IntUnit> Point2<T>

pub fn saturating_add(self, rhs: Self) -> Self

Returns a vector containing the saturating addition of self and rhs.

pub fn saturating_sub(self, rhs: Self) -> Self

Returns a vector containing the saturating subtraction of self and rhs.

pub fn saturating_mul(self, rhs: Self) -> Self

Returns a vector containing the saturating multiplication of self and rhs.

pub fn saturating_div(self, rhs: Self) -> Self

Returns a vector containing the saturating division of self and rhs.

pub fn wrapping_add(self, rhs: Self) -> Self

Returns a vector containing the wrapping addition of self and rhs.

pub fn wrapping_sub(self, rhs: Self) -> Self

Returns a vector containing the wrapping subtraction of self and rhs.

pub fn wrapping_mul(self, rhs: Self) -> Self

Returns a vector containing the wrapping multiplication of self and rhs.

pub fn wrapping_div(self, rhs: Self) -> Self

Returns a vector containing the wrapping division of self and rhs.

Source

impl<T: Unit> Point2<T>

pub fn swizzle<const X: usize, const Y: usize>(&self) -> Vector2<T>

Select components of this vector and return a new vector containing those components.

Source

impl<T: Unit> Point2<T>

pub const ZERO: Self

All zeroes.

pub const ONE: Self

All ones.

pub const X: Self

Unit vector in the direction of the X axis.

pub const Y: Self

Unit vector in the direction of the Y axis.

pub const AXES: [Self; 2]

The unit axes.

pub fn to_raw(self) -> <T::Scalar as Scalar>::Vec2

Transparently cast this type to its underlying, bitwise compatible glam type.

pub fn from_raw(vec: <T::Scalar as Scalar>::Vec2) -> Self

Convert a raw glam vector to this type. This is a zero-overhead cast.

Source

impl<T: FloatUnit> Point2<T>

pub const NAN: Self

All NaN.

pub const INFINITY: Self

All positive infinity.

pub const NEG_INFINITY: Self

All negative infinity.

pub fn is_nan_mask(self) -> BVec2

Return a mask where each bit is set if the corresponding component is NaN.

pub fn is_finite_mask(self) -> BVec2

Performs is_finite on each element of self, returning a vector mask of the results.

Source

impl<T: SignedUnit> Point2<T>

pub const NEG_ONE: Self

All negative one.

pub const NEG_X: Self

(-1, 0)

pub const NEG_Y: Self

(0, -1)

Source

impl<T: Unit> Point2<T>

pub fn from_array(array: [T::Scalar; 2]) -> Self

Creates a new vector from an array.

pub fn to_array(&self) -> [T::Scalar; 2]

[x, y]

pub fn extend(self, z: T::Scalar) -> Point3<T>

Creates a 3D vector from self and the given z value.

pub fn cmpeq(self, rhs: Self) -> BVec2

Returns a vector mask containing the result of a == comparison for each element of self and rhs.

pub fn cmpne(self, rhs: Self) -> BVec2

Returns a vector mask containing the result of a != comparison for each element of self and rhs.

pub fn cmpge(self, rhs: Self) -> BVec2

Returns a vector mask containing the result of a >= comparison for each element of self and rhs.

pub fn cmpgt(self, rhs: Self) -> BVec2

Returns a vector mask containing the result of a > comparison for each element of self and rhs.

pub fn cmple(self, rhs: Self) -> BVec2

Returns a vector mask containing the result of a <= comparison for each element of self and rhs.

pub fn cmplt(self, rhs: Self) -> BVec2

Returns a vector mask containing the result of a < comparison for each element of self and rhs.

pub fn select(mask: BVec2, if_true: Self, if_false: Self) -> Self

Creates a vector from the elements in if_true and if_false, selecting which to use for each element of self.

A true element in the mask uses the corresponding element from if_true, and false uses the element from if_false.

Source

impl<T: FloatUnit> Point2<T>

pub fn distance_squared(self, other: Self) -> T::Scalar

Compute the squared euclidean distance between two points in space.

pub fn distance(self, other: Self) -> T::Scalar

Computes the Euclidean distance between two points in space.

pub fn midpoint(self, rhs: Self) -> Self

Calculates the midpoint between self and rhs.

See (e.g.) glam::Vec2::midpoint().

pub fn move_towards(&self, rhs: Self, d: T::Scalar) -> Self

Moves towards rhs based on the value d.

See (e.g.) glam::Vec2::move_towards().

Source

impl<T: IntUnit<Scalar: IntScalar>> Point2<T>

pub fn manhattan_distance( self, other: Self, ) -> <T::Scalar as IntScalar>::Unsigned

Computes the manhattan distance between two points

pub fn checked_manhattan_distance( self, other: Self, ) -> Option<<T::Scalar as IntScalar>::Unsigned>

Computes the manhattan distance between two points

pub fn chebyshev_distance( self, other: Self, ) -> <T::Scalar as IntScalar>::Unsigned

Compute the chebyshev distance between two points.